@@ -172,9 +172,6 @@ class PackageStatusBar(StatusBar):
             "changed", self._on_combo_multiple_versions_changed)
         self.progress = Gtk.ProgressBar()
 
-        # theme engine hint for bug #606942
-        self.progress.set_data("transparent-bg-hint", True)
-
         self.pkg_state = None
 
         self.hbox.pack_start(self.installed_icon, False, False, 0)
@@ -1475,11 +1472,12 @@ class AppDetailsView(Viewport):
             version = utf8(_("%s (unknown version)")) % utf8(
                 app_details.pkgname)
         if app_details.license:
-            license = app_details.license
+            license = GObject.markup_escape_text(app_details.license)
         else:
             license = _("Unknown")
         if app_details.maintenance_status:
-            support = app_details.maintenance_status
+            support = GObject.markup_escape_text(
+                app_details.maintenance_status)
         else:
             support = _("Unknown")
         # regular label updates
@@ -1567,6 +1565,7 @@ class AppDetailsView(Viewport):
         self._update_pkg_info_table(app_details)
         self._update_warning_bar(app_details)
 #        self._update_addons_minimal(app_details)
+        self._update_app_video(app_details)
 
         # depending on pkg install state set action labels
         self.pkg_statusbar.configure(app_details, app_details.pkg_state)
@@ -1737,7 +1736,7 @@ class AppDetailsView(Viewport):
             # update all (but skip the addons calculation if this is a
             # DebFileApplication as this is not useful for this case and it
             # increases the view load time dramatically)
-            skip_update_addons = type(self.app) == DebFileApplication
+            skip_update_addons = isinstance(self.app, DebFileApplication)
             self._update_all(self.app_details,
                              skip_update_addons=skip_update_addons)
 
@@ -1913,7 +1912,9 @@ class AppDetailsView(Viewport):
                 self.pkg_statusbar.progress.set_fraction(progress / 100.0)
             if progress >= 100:
                 self.pkg_statusbar.progress.set_fraction(1)
-                self.adjustment_value = self.get_vadjustment().get_value()
+                adj = self.get_vadjustment()
+                if adj:
+                    self.adjustment_value = adj.get_value()
 
     def get_app_icon_details(self):
         """ helper for unity dbus support to provide details about the
@@ -2010,7 +2011,7 @@ class AppDetailsView(Viewport):
             self.addons_manager.addons_to_remove,
             self.app.archive_suite)
         total_download_size, total_install_size = res
-        if res == (0, 0) and type(self.app) == DebFileApplication:
+        if res == (0, 0) and isinstance(self.app, DebFileApplication):
             total_install_size = self.app_details.installed_size
         if total_download_size > 0:
             download_size = GLib.format_size(total_download_size)
@@ -2022,10 +2023,14 @@ class AppDetailsView(Viewport):
               self.app_details.pkg_state == PkgStates.INSTALLED and
               not self.addons_manager.addons_to_install and
               not self.addons_manager.addons_to_remove):
-            pkg = self.cache[self.app_details.pkgname].installed
-            install_size = GLib.format_size(pkg.installed_size)
-            # FIXME: this is not really a good indication of the size on disk
-            label_string += _("%s on disk") % (install_size)
+            pkg_version = self.cache[self.app_details.pkgname].installed
+            # we may not always get a pkg_version returned (LP: #870822),
+            # in that case, we'll just have to display "Unknown"
+            if pkg_version:
+                install_size = GLib.format_size(pkg_version.installed_size)
+                # FIXME: this is not really a good indication of the size
+                # on disk
+                label_string += _("%s on disk") % (install_size)
         elif total_install_size < 0:
             remove_size = GLib.format_size(-total_install_size)
             label_string += _("%s to be freed") % (remove_size)
@@ -2038,7 +2043,7 @@ class AppDetailsView(Viewport):
         self.section = section
 
 
-def get_test_window_appdetails():
+def get_test_window_appdetails(pkgname="totem"):
 
     from softwarecenter.db.pkginfo import get_pkg_info
     cache = get_pkg_info()
@@ -2064,12 +2069,6 @@ def get_test_window_appdetails():
     scroll = Gtk.ScrolledWindow()
     view = AppDetailsView(db, distro, icons, cache, datadir)
 
-    import sys
-    if len(sys.argv) > 1:
-        pkgname = sys.argv[1]
-    else:
-        pkgname = "totem"
-
     view.show_app(Application("", pkgname))
     #view.show_app(Application("Pay App Example", "pay-app"))
     #view.show_app(Application("3D Chess", "3dchess"))
@@ -2101,7 +2100,13 @@ if __name__ == "__main__":
             view.show_app(Application("Movie Player", "totem"))
         return True
 
-    win = get_test_window_appdetails()
+    import sys
+    if len(sys.argv) > 1:
+        pkgname = sys.argv[1]
+    else:
+        pkgname = "totem"
+
+    win = get_test_window_appdetails(pkgname=pkgname)
 
     # keep it spinning to test for re-draw issues and memleaks
     #view = win.get_data("view")
